#
# spec file for package libxslt
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libxslt
%define soname  1
%define exslt_soname 0
Version:        1.1.28
Release:        9.5
Summary:        XSL Transformation Library
License:        MIT and GPL-2.0+
Group:          System/Libraries
#
Url:            http://xmlsoft.org/XSLT/
Source:         ftp://xmlsoft.org/libxslt/libxslt-%{version}.tar.gz
Source2:        baselibs.conf
Source3:        xslt-config.1.gz
Patch0:         %{name}-1.1.24-no-net-autobuild.patch
Patch1:         libxslt-config-fixes.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libgcrypt-devel
BuildRequires:  libgpg-error-devel
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  pkg-config
# bug437293
%ifarch ppc64
Obsoletes:      libxslt-64bit
%endif

%description
This C library allows you to transform XML files into other XML files
(or HTML, text, and more) using the standard XSLT stylesheet
transformation mechanism.

It is based on libxml (version 2) for XML parsing, tree manipulation,
and XPath support. It is written in plain C, making as few assumptions
as possible and sticks closely to ANSI C/POSIX for easy embedding.
Although not primarily designed with performance in mind, libxslt seems
to be a relatively fast processor. It also includes full support for
the EXSLT set of extension functions as well as some common extensions
present in other XSLT engines.

%package -n %{name}%{soname}
Summary:        XSL Transformation Library
License:        LGPL-2.1+
Group:          System/Libraries
%if 0%{?suse_version} < 1220
Provides:       %{name}-tools = %{version}
%endif

%description -n %{name}%{soname}
This C library allows you to transform XML files into other XML files
(or HTML, text, and more) using the standard XSLT stylesheet
transformation mechanism.

It is based on libxml (version 2) for XML parsing, tree manipulation,
and XPath support. It is written in plain C, making as few assumptions
as possible and sticks closely to ANSI C/POSIX for easy embedding.
Although not primarily designed with performance in mind, libxslt seems
to be a relatively fast processor. It also includes full support for
the EXSLT set of extension functions as well as some common extensions
present in other XSLT engines.

The package comes with xsltproc, a command line interface to the XSLT
engine.

%package devel
Summary:        Include Files and Libraries mandatory for Development
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
# bug437293
%ifarch ppc64
Obsoletes:      %{name}-devel-64bit
%endif
%if 0%{?suse_version} >= 1220
Requires:       %{name}-tools = %version
%endif
Requires:       %{name}%{soname} = %{version}
Requires:       glibc-devel
Requires:       libgcrypt-devel
Requires:       libgpg-error-devel
#libxml is automatically required with pkgconfig

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%if 0%{?suse_version} >= 1220
%package tools
Summary:        Extended Stylesheet Language (XSL) Transformation utilities
License:        MIT and GPL-2.0+
Group:          Development/Tools
Provides:       xsltproc = %version-%release
# O/P added during 12.2 dev:
Obsoletes:      %{name} < %version-%release
Provides:       %{name} = %version-%release

%description tools
This package contains xsltproc, a command line interface to the XSLT engine.
%endif

%prep
%setup -q
%patch0
%patch1

%build
autoreconf --force --install --verbose
%configure --disable-static --with-pic --without-python --disable-silent-rules
make %{?_smp_mflags}

%check
%if ! 0%{?qemu_user_space_build}
make check
%endif

%install
%makeinstall

# Unwanted doc stuff
rm -fr %{buildroot}%{_datadir}/doc

# the manual page is required
install -ma=r '-t%{buildroot}%{_mandir}/man1' '%{SOURCE3}'

#kill all "la" files
find %{buildroot} -type f -name "*.la" -print -delete

%post -n %{name}%{soname} -p /sbin/ldconfig

%postun -n %{name}%{soname} -p /sbin/ldconfig

%files -n %{name}%{soname}
%defattr(-, root, root)
%{_libdir}/libxslt.so.%{soname}
%{_libdir}/libxslt.so.%{soname}.*
%{_libdir}/libexslt.so.%{exslt_soname}
%{_libdir}/libexslt.so.%{exslt_soname}.*
%if 0%{?suse_version} >= 1220
%files tools
%defattr(-,root,root)
%endif
%doc AUTHORS NEWS README COPYING* Copyright TODO FEATURES
%{_bindir}/xsltproc
%doc %{_mandir}/man1/xsltproc.*

%files devel
%defattr(-, root, root)
%{_libdir}/libxslt.so
%{_libdir}/libexslt.so
%{_libdir}/*.sh
%{_libdir}/pkgconfig/libxslt.pc
%{_libdir}/pkgconfig/libexslt.pc
%{_includedir}/*
%{_datadir}/aclocal/*
%{_bindir}/xslt-config
%doc %{_mandir}/man1/xslt-config.*
%doc %{_mandir}/man3/*
# not available doc/*.png
%doc doc/*.html doc/html doc/tutorial doc/*.gif

%changelog
* Thu Dec  6 2012 pascal.bleser@opensuse.org
- update to 1.1.28:
  * fix generate-id() to avoid generating the same ID
  * fix crash with empty xsl:key/@match attribute
  * fix crash when passing an uninitialized variable to document()
  * fix regression: default namespace not correctly used
  * remove xsltTransStorageAdd and xsltTransStorageRemove from symbols.xml
- changes from 1.1.27:
  * link python module with python library (Frederic Crozat)
  * report errors on variable use in key
  * the XSLT namespace string is a constant one
  * fix handling of names in xsl:attribute
  * reserved namespaces in xsl:element and xsl:attribute
  * null-terminate result string of cry:rc4_decrypt
  * EXSLT date normalization fix
  * exit after compilation of invalid func:result
  * fix for EXSLT func:function
  * rewrite EXSLT string:replace to be conformant
  * avoid a heap use after free error
  * fix a dictionary string usage
  * output should not include extraneous newlines when indent is off
  * document('') fails to return stylesheets parsed from memory
  * xsltproc should return an error code if xinclude fails
  * forwards-compatible processing of unknown top level elements
  * fix system-property with unknown namespace
  * fix default template processing on namespace nodes
  * fix a bug in selecting XSLT elements
  * fix a memory leak with xsl:number
  * fix a problem with ESXLT date:add() with January
  * fix generate-id() to not expose object addresses
  * allow whitespace in xsl:variable with select
  * fix direct pattern matching bug
  * add the saxon:systemId extension
  * add an append mode to document output
  * fix portability to upcoming libxml2-2.9.0
  * precompile patterns in xsl:number
- change soname macro back to "1" and enforce it in the files list
- revert -tools subpackage for openSUSE < 12.2 as that has only
  become effective since 12.2 on the package that ships with the
  distribution, to avoid having a completely different package
  layout in this repository as compared to the stock distribution
  packages (added a Provides: libxslt-tools though)
* Wed Apr 25 2012 chris@computersalat.de
- add macro "soname" %%{name}1
- fix "self obsoletion"
* Sat Mar 17 2012 jengelh@medozas.de
- Make sure to follow shlib policy; put tools in a separate package
  like done in libxml2
* Wed Jan  4 2012 jengelh@medozas.de
- Remove redundant tags (License: field is inherited)
- Use exact EVR for Provides:
* Wed Jan  4 2012 cfarrell@suse.com
- Tutorial contains GPL-2.0+ code. Either split this off into a subpackage or
  add GPL-2.0+ as an aggregation to the main licence tag
* Sat Dec  3 2011 agraf@suse.com
- don't run make check in QEMU builds - breaks due to massive threading
* Mon Nov 21 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Sep  8 2011 dmueller@suse.de
- fix provides/obsoletes
* Tue Aug  2 2011 idonmez@novell.com
- Add dependency on libgcrypt-devel and libgpg-error-devel for
  the libxslt-devel package
* Mon Aug  1 2011 idonmez@novell.com
- Correctly obsolete libxslt package in the baselibs.conf too
* Fri Jul 29 2011 idonmez@novell.com
- Fix build on SLE
* Fri Jul 29 2011 crrodriguez@opensuse.org
- Fix broken requires,provides,Obsoletes causing "have choice.."
  build system errors
- Remove all "la" files since they are no longer needed
- Fix -devel pacakge requires and messed up -config scripts
  this may cause build fails of already broken dependant packages
  that do not link all the needed libraries in an explicit manner
  (This is not a bug here, it is expected to cause it)
* Wed Jul 27 2011 giecrilj@stegny.2a.pl
- package clean-up:
  - include library version number in the name of the binary package
  - add an alias for xsltproc (required by package xmlto)
* Wed Jul 21 2010 puzel@novell.com
- update to libxslt-1.1.26
  - Improvements:
  - Add xsltProcessOneNode to exported symbols for lxml
  - Features:
  - Add API versioning and various cleanups
  - xsl:sort lang support using the locale
  - Bug fixes
  - Portability, documentation fixes
- drop libxslt-1.1.24-rc4-overflow.patch (included upstream)
- drop libxslt-1.1.24-am.patch (included upstream)
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Sun Jun 21 2009 coolo@novell.com
- fix build with automake 1.11
* Fri Feb 13 2009 coolo@suse.de
- fix file list
* Wed Feb 11 2009 coolo@suse.de
- readd "la" files to fix libxslt-python build
* Mon Jan 26 2009 crrodriguez@suse.de
- remove useless "la" file
- remove static libraries, if something breaks, move libraries to /%%{_lib}
  instead of restoring them
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Fri Jul 18 2008 prusnak@suse.cz
- updated to 1.1.24:
  * documentation: man page fix
  * bug fixes: pattern bug fix, key initialization problems,
    exclusion of unknown namespaced element on top of stylesheets
    python generator syntactic cleanup
- dropped obsoleted CVE-2008-1767.patch (included in update)
- fixed overflow in RC4 code (rc4-overflow.patch) [bnc#410256]
* Mon May 19 2008 prusnak@suse.cz
- fixed CVE-2008-1767 (CVE-2008-1767.patch) [bnc#391920]
* Fri Apr 11 2008 prusnak@suse.cz
- updated to 1.1.23
  * Documentation
    fix links for Cygwin DocBook setup (Philippe Bourcier)
  - xsltParseStylesheetDoc doc fix (Jason Viers)
  - fix manpage default maxdepth value
  * Bug fixes:
  - python segfault (Daniel Gryniewicz)
  - week-in-year bug fix (Maurice van der Pot)
  - fix python iterator problem (William Brack)
  - avoid garbage collection problems on str:tokenize and str:split
    and function results (William Brack and Peter Pawlowski)
  - superfluous re-generation of keys (William Brack)
  - remove superfluous code in xsltExtInitTest (Tony Graham)
  - func:result segfault fix (William Brack)
  - timezone offset problem (Peter Pawlowski),
  * Portability fixes:
  - old gcrypt support fix (Brent Cowgill)
  - Python portability patch (Stephane Bidoul)
  - VS 2008 fix (Rob Richard)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Jan 22 2008 prusnak@suse.cz
- build --without-python to allow compilation from src.rpm
* Tue Sep 18 2007 sbrabec@suse.cz
- Updated to version 1.1.22:
  * Bug fixes: RVT cleanup problems, exclude-result-prefix bug,
    stylesheet compilation error handling, out of memory allocation
    errors, namespace problem on compound predicates, python
    space/tab inconsistencies, hook xsl:message to per
    transformation error callbacks, cached RVT problem, XPath
    context maintainance on choose, memory leaks in the math
    module, exclude-result-prefix induced namespace problem
  * Portability fixes: improve build with VS2005, fixing build on
    AIX, fix the security file checks on Windows.
  * Improvement: add an --encoding option to xsltproc.
  * Build: configure setup for TRIO_REPLACE_STDIO
  * Documentation: updated after change from CVs to SVN
* Thu Jan 25 2007 prusnak@suse.cz
- update to 1.1.20
  * result Value Tree handling fix
  * function parameters fix
  * empty text node handling
  * plugin support and test fixes
  * fragment support fixes
  * python stylesheet compare and transform context access
  * EXSLT string replace support
  * xsltproc better low level error handling
- fixed crash on ENOMEM (null-retval.patch) [#215223]
- drop obsolete patches:
  * libxslt-aliasing.patch (included in update)
  * libxslt-transform.patch (included in update)
* Thu Dec 21 2006 ro@suse.de
- fix for crash with certain transformations (libxcb build crash)
* Tue Dec 12 2006 ke@suse.de
- 1.1.19; NEWS extract:
  * Bug fixes: entities within attributes; in-scope namespace bug, result
  value tree caching bug, a number of namespace related bugs, etc.
  * Improvements: refactoring of namespace handling, value-of
  impleemntation and template internal processing, new xsltproc flag to
  apply Xinclude to stylesheets.
  * Documentation.
* Fri Oct 27 2006 dmueller@suse.de
- update --nonet patch to work even when using rpmbuild directly
* Tue Oct 24 2006 dmueller@suse.de
- make --nonet default while building packages (#214338)
* Tue Oct 17 2006 ke@suse.de
- Move devel docs to the -devel subpackage; reported by Andreas Hanke [#
  212441].
* Fri Jun 16 2006 ke@suse.de
- 1.1.17:
  * Bug fixes: some regression tests, attribute/namespaces output,
    problem in mixed xsl:value-of and xsl:text uses.
  * Improvements: internal refactoring, use of the XPath object cache in
    libxml2-2.6.25.
- Require libxml2-2.2.25.
* Tue May 23 2006 ke@suse.de
- Update to version 1.1.16:
  * Bug fixes (pattern compilation, namespace prefixes, etc.).
  * Speed up sorting.
  * Documentation update.
- Adjust warn patch; drop libxslt-xpath-pattern.patch.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct 11 2005 ke@suse.de
- On account of pattern.c, add -fno-strict-aliasing again.
- Also require glibc-devel.
* Tue Oct  4 2005 ke@suse.de
- libxslt-xpath-pattern.patch:
  libxslt/pattern.c: fixed problem in internal XPath compilation
  of patterns including variables, fixes GNOME bug #316861
  (William Brack).  Reported by Andreas Jaeger/Uwe Gansert.
* Fri Sep 30 2005 aj@suse.de
- Fix compiler warnings.
- Add missing requires.
* Fri Sep 16 2005 ke@suse.de
- Update to version 1.1.15; NEWS from  http://xmlsoft.org/XSLT/ :
  * Bug fixes and improvements.
  * Documentation enhancement.
* Wed Jul  6 2005 meissner@suse.de
- fixed strict aliasing problem.
* Mon Apr  4 2005 ke@suse.de
- Update to version 1.1.14; some NEWS (extract since .13) from
  http://xmlsoft.org/XSLT/ :
  * Extensions: module support; dictionnary based speedups trying to get
    rid of xmlStrEqual as much as possible.
  * Bugfixes:
    exslt day-of-week-in-month, xsl:call-template should not change the
    current template rule, evaluation of global variables, RVT's in
    XPath predicates, namespace URI on template names, pattern
    expression fixes, out of memory detection misses, parserOptions
    propagation, exclude-result-prefixes fix, // patten fix,  text node
    on stylesheet document without a dictionary, more checking of XSLT
    syntax, calling xsltInit() multiple times, bug in pattern matching
    with ancestors, bug in pattern matching with cascading select,
    xinclude and document() problem.
- CFLAGS: Add -fno-strict-aliasing.
* Fri Dec 10 2004 ke@suse.de
- Do not list manpages twice; reported by Chris Lahey [Novell #472] and
  [# 49118].
* Tue Nov  2 2004 ke@suse.de
- Update to version 1.1.12; some NEWS from http://xmlsoft.org/XSLT/ :
  * Bug fixes: attribute document pointer fix, exslt date negative
    periods, generated tree structure fixes, namespace lookup fix, use
    reentrant gmtime_r, exslt:funtion namespace fix, potential NULL
    pointer reference, force string interning on generated documents.
  * Improve documentation.
* Fri Oct  8 2004 ke@suse.de
- Update to version 1.1.11; some NEWS from http://xmlsoft.org/XSLT/
  (since 1.1.9):
  * Bug fixes: xsl:include problems, UTF8 number pattern, date-time
    validation, namespace fix, various Exslt date fixes, error callback
    fixes, leak with namespaced global variable, attempt to fix a weird
    problem (Gnome Bugzilla #153137), key initialization problem.
  * Improvements: exslt:date-sum tests.
  * Documentation: Second tutorial by Panagiotis Lourida.
- Enable crypto support [#44119].
* Mon Aug 23 2004 ke@suse.de
- Update to version 1.1.9; some NEWS from http://xmlsoft.org/XSLT/
  * Various bug fixes (RVT key handling, Python bindings, key and XPath,
    64bit issue, etc.).
* Thu Aug 19 2004 schwab@suse.de
- Fix a broken cast.
* Wed Jul 14 2004 ke@suse.de
- Update to version 1.1.8; some NEWS from http://xmlsoft.org/XSLT/ :
  * Bug fixes.
* Fri May 21 2004 ke@suse.de
- Update to version 1.1.7; some NEWS from http://xmlsoft.org/XSLT/ :
  * Bugfixes: UTF-8 string tokenize, fix subtle memory corruption,
    linefeed after comment at document level, disable-output-escaping
    problem, pattern compilation in deep imported stylesheets,
    namespace extension prefix bug, namespace lookup for attribute,
    namespaced DOCTYPE name.
* Tue Apr 20 2004 ke@suse.de
- Update to version 1.1.6; some NEWS from
  http://xmlsoft.org/XSLT/ (since 1.1.2):
  * Performance improvements (e.g., dictionnary reuses for XSLT).
  * Various bugfixes (keys, thread troubles, tokenize fix for UTF-8,
  xpath, etc.).
  * Documentation cleanup.
- Drop obsolete patch (libxslt-m4.diff).
* Mon Mar 15 2004 ke@suse.de
- libxslt-m4.diff: Quote first argument of AC_DEFUN; reported by Dirk
  Mueller [# 35887].
* Mon Jan 12 2004 adrian@suse.de
- build as user
* Wed Jan  7 2004 ke@suse.de
- Update to version 1.1.2; NEWS from http://xmlsoft.org/XSLT/:
  * Documentation fixes; EXSLT documentation.
  * Bug fixes: exslt:date returning NULL strings, namespaces output,
    key and namespace definition problem, passing options down to
    the document() parser, xsl:number fixes.
* Fri Dec 12 2003 ke@suse.de
- Update to version 1.1.1; NEWS from http://xmlsoft.org/XSLT/:
  * bug fixes: number formatting, exslt:tokenize, key selector parsing
    with |, xsl:element with computed namespaces, xslt:import/include
    recursion detection, exslt:function used in keys, bug when
    CDATA_SECTION are found in the tree, entities handling when using
    XInclude.
* Wed Nov  5 2003 ke@suse.de
- Update to version 1.1.0; NEWS from http://xmlsoft.org/XSLT/:
  * Make use of the new libxml2 API.
  * Remove DocBook SGML broken support.
  * Remove the deprecated breakpoint library
  * Fixes: xsl:key to work with PIs, extension memory error fix, header
    path, some tortuous template problems when using predicates, a bug
    in default processing of attributes, detect invalid names on
    templates, exslt:document (and similar) base handling problem,
  * xsltproc option display fix,
  * Python: never use stdout for error.
* Tue Oct  7 2003 ke@suse.de
- Update to version 1.0.33; NEWS from http://xmlsoft.org/XSLT/:
  * mode not cascaded in template fallbacks.
  * catch redefinition of parameter/variables.
  * multiple keys with same namespace name.
  * cdata-section-elements handling of namespaced names.
  * apply-templates crash.
  * bug with imported templates.
  * imported attribute-sets merging bug (DocBook).
* Thu Sep 18 2003 sf@suse.de
- Do not free the hash keys during xmlHashScanFull,
  it will corrupt the hash table. The keys will be
  freed by xmlHashFree right afterwards anyway. #30506
* Fri Aug 15 2003 ke@suse.de
- Update to version 1.0.32; NEWS from http://xmlsoft.org/XSLT/:
  * Bugfixes: xsltSaveResultToFile() python binding, EXSLT fixes,
    speed of large text output, xsl:copy with attributes, strip-space and
    namespaces prefix, fix for --path xsltproc option, sort with multiple
    keys, checking of { and } for attribute value templates.
  * Python bindings for extension elements.
  * Doc cleanup.
* Wed Jul  9 2003 ke@suse.de
- Update to version 1.0.31; NEWS from http://xmlsoft.org/XSLT/:
  * Bugfixes: xsl:copy on namespace nodes, AVT for xsl:sort order, fix
    for the debugger, output filename limitation, trio.h and triodef.h
    added, EXSLT node-set, xsltChoose and whitespace, stylesheet
    compilation, NaN and sort.
  * Avoid generating &quot; (fix in libxml2-2.5.8)
* Tue Jun 17 2003 sbrabec@suse.cz
- Updated to version 1.0.30.
- Fixed linking of libxsltbreakpoint.
* Mon May 26 2003 ke@suse.de
- Remove unwanted files from $RPM_BUILD_ROOT.
* Wed Apr  2 2003 ke@suse.de
- Update to version 1.0.29; NEWS from http://xmlsoft.org/XSLT/:
  Significant speedup for large (flat) documents which also requires
  libxml2-2.5.6:
  * Bug fixes: Result Value Tree handling, XML IDs, keys(), extra namespace
    declarations with xsl:elements.
* Wed Mar 26 2003 ke@suse.de
- Update to version 1.0.28; NEWS from http://xmlsoft.org/XSLT/:
  * Fix node() in patterns semantic.
  * Fix a memory access problem in format-number()
  * Fix stack overflow in recursive global variable or params
  * Clean up Result Value Tree handling, and fix a couple of
  old bugs in the process.
* Tue Feb 11 2003 ke@suse.de
- Update to version 1.0.26; NEWS from http://xmlsoft.org/XSLT/:
  * Fixed 3 serious bugs in document() and stylesheet compilation which
    could lead to a crash.
* Thu Feb  6 2003 ke@suse.de
- Update to version 1.0.24; NEWS from http://xmlsoft.org/XSLT/:
  * Bug fixes: double-free for standalone stylesheets introduced in
    1.0.24, C syntax pbm, etc.
  * Some XPath and XInclude related problems were actually fixed in
    libxml2-2.5.2.
  * Documentation: emphasize that --docbook is not for XML docs.
* Wed Jan 15 2003 ke@suse.de
- Update to version 1.0.24; NEWS from http://xmlsoft.org/XSLT/:
  A lot of bug fixes and a few improvements:
  * Bug fixes: imported global varables, python bindings, EXSLT memory
    leak, namespace generation on xsl:attribute, space handling with
    imports, extension-element-prefixes, comments within xsl:text,
    superfluous xmlns generation, XInclude related bug for numbering,
    EXSLT strings, attribute-sets computation on imports, extension module
    init and shutdown callbacks not called.
  * Add xsltGetProfileInformation().
  * Fix API generation scripts.
  * API to provide the sorting routines.
  * Add XML description of the EXSLT API.
  * Add ESXLT URI (un)escaping.
  * Fix some memory leaks.
  * document() now supports fragment identifiers in URIs.
* Tue Nov 26 2002 ro@suse.de
- split libxslt-python to own specfile
  (libxslt is turning more and more into a base package
  and python requires a lot of other things to build)
- removed gtkdoc from neededforbuild (html is not rebuilt anyway)
* Mon Nov 18 2002 ke@suse.de
- Update to version 1.0.23; NEWS from http://xmlsoft.org/XSLT/:
  * Improvement of the python bindings: extension functions and
    activating EXSLT.
  * various bug fixes: number formatting, portability for bounded string
    functions, CData nodes, key(), @*[...] patterns.
  * Documentation improvements.
  * Add libxslt.m4.
- Require libxml2 2.4.27.
* Thu Oct 31 2002 ke@suse.de
- Update to version 1.0.22; NEWS from http://xmlsoft.org/XSLT/:
  * Add a security module, and a related set of new options to xsltproc.
  * Allow per transformation error handler.
  * Fix a few bugs: node() semantic, URI escaping, media-type, attribute
  lists.
* Wed Oct  9 2002 ke@suse.de
- Update to version 1.0.21; NEWS from http://xmlsoft.org/XSLT/:
  * Bug  fixes:  match="node()",  date:difference(), disable-output-escaping
  * Mem leak fix.
  * Python bindings: style.saveResultToString().
  * Documentation improvements.
  * try  to  handle  document('') as best as possible depending in the
  cases
  * Fix the DocBook stylesheets handling problem
  * Fix a few XSLT reported errors
- Drop namespace patch (already included).
* Tue Aug 20 2002 ke@suse.de
- Apply patch by Daniel Veillard to fix a namespace problem raised by
  recent DocBook stylesheets
  (cf. http://bugzilla.gnome.org/show_bug.cgi?id=87901).
  Reported by Stephan Kulow [# 18099].
* Wed Jul 31 2002 ke@suse.de
- Run %%run_ldconfig.
* Mon Jul  8 2002 ke@suse.de
- Update to version 1.0.19; NEWS from http://xmlsoft.org/XSLT/, not
  mentioned earlier:
  * Bug fixes: attributes, extra namespace declarations (DocBook),
    xsl:include crash, documentation, element-available.
  * xsltproc can now list registered extensions.
  * New API to save directly to a string xsltSaveResultToString().
  * Specific error registration function for the python API.
* Wed May 29 2002 ro@suse.de
- tweak python installation some more for lib64
* Tue May 28 2002 ke@suse.de
- Update to 1.0.18:
  - Add Pyhton bindings (libxslt-python).
  - Bug fixes.
  - New man page for libexslt.
* Tue Apr 30 2002 ke@suse.de
- Update to version 1.0.17; NEWS from http://xmlsoft.org/XSLT/ :
  o EXSLT date improvement and regression tests.
  o Attempt to fix a bug in xsltProcessUserParamInternal.
* Fri Apr 19 2002 ke@suse.de
- Update to version 1.0.16; NEWS from http://xmlsoft.org/XSLT/ :
  o Bug fixes: strip-space, URL in HTML output, error when xsltproc
    can't save.
  o Improve Python bindings.
* Tue Apr  9 2002 ke@suse.de
- Update to version 1.0.15; NEWS since 1.0.9 from http://xmlsoft.org/XSLT/ :
  * Change of Licence to the MIT Licence.
  * Bugfixes: XPath, python Makefile, recursive attribute sets,
    @foo[..] templates.
  * Fix a bug raised when using doctypes with HTML output.
  * More EXSLT functions.
  * Provide fixes and regression tests for exslt date functions.
  * Nasty bug fix related to exslt:node-set.
  * Fix bug "namespace node have no parents".
  * Obsoleted libxsltbreakpoint now deprecated and frozen to 1.0.8 API
  * xsltproc return codes are now significant, update documentation.
  * Debug of memory alocation with valgind.
  * Patch to allow as much as 40 steps in patterns.
  * Enhancements to interface with xsltdebugger.
  * Added a stringparam option to avoid escaping hell at the shell level.
  * serious profiling leading to significant improvement for DocBook
    processing.
  * Improvement in the XPath engine (libxml2-2.4.18).
  * Add Python bindings.
  * Documentation changes and updates.
* Wed Feb 20 2002 olh@suse.de
- fix prefix tag to build shared libs
* Tue Feb 12 2002 adrian@suse.de
- fix build for s390x
* Tue Dec 11 2001 ro@suse.de
- use less intrusive hack for libtool: export LIBRARY_PATH
* Thu Nov 29 2001 ro@suse.de
- install without buildroot first to work around libtool
  not being able to cope with dependant libraries and buildroot
* Tue Nov 27 2001 ke@suse.de
- Update to version 1.0.8; NEWS from http://xmlsoft.org/XSLT/ :
  - Previous header patch is superfluous.
  - Bug fixes.
* Tue Nov 20 2001 ke@suse.de
- Add missing define; cf.
  http://mail.gnome.org/archives/xslt/2001-November/msg00052.html .
- NEWS for 1.0.7 entries from http://xmlsoft.org/XSLT/ (not
  mentioned earlier):
  - Fix handling of indent="no" on HTML output.
* Sat Nov 10 2001 adrian@suse.de
- Update to version 1.0.7
- add fixes for automake 1.5
* Sat Nov  3 2001 ro@suse.de
- fix for automake 1.5
* Wed Oct 31 2001 ke@suse.de
- Update to version 1.0.6; NEWS from http://xmlsoft.org/XSLT/ :
  - Bug fixes on number formatting and date/time functions.
  - Fix DOCTYPE generation rules for HTML output.
* Thu Oct 11 2001 ke@suse.de
- Update to version 1.0.5; NEWS from http://xmlsoft.org/XSLT/ :
  - Portability fixes.
  - Fix a dozen bugs on XSLT and EXSLT.
  - Add support for Saxon's evaluate and expressions extensions.
  - Better handling of XPath evaluation errors.
* Mon Oct  1 2001 ke@suse.de
- Update to version 1.0.4; NEWS from http://xmlsoft.org/XSLT/ :
  - Documentation updates.
  - Bug fixes (DocBook FO generation should be fixed) and portability
    improvements.
  - Improve existing EXSLT support and add String, Time and Date core
    functions support.
* Fri Aug 24 2001 ke@suse.de
- Update to version 1.0.3; from the announcement (cf. libxml2):
  - Implement XML Catalog Specification from August 6:
    http://www.oasis-open.org/committees/entity/spec-2001-08-06.html
    http://xmlsoft.org/catalog.html
  - New NaN and Infinity code.
  - A number of small bugfixes.
* Fri Aug 17 2001 ke@suse.de
- Update to version 1.0.2.
- Call 'libtoolize' and friends.
* Wed Jul 11 2001 ke@suse.de
- New package: version 1.0.0.
